SystemOrganization addCategory: #'Metacello-Base'!

Object subclass: #MetacelloBaseConfiguration
	instanceVariableNames: 'project'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-Base'!

!MetacelloBaseConfiguration class methodsFor: 'private' stamp: 'DaleHenrichs 11/2/2010 14:03'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!MetacelloBaseConfiguration class methodsFor: 'private' stamp: 'DaleHenrichs 11/2/2010 14:03'!
ensureMetacello
	"Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
	 Gofer API), then load the latest version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [ | error |
		"list of repositories to try, in case primary repository is not accessible"
		(Array 
			with: 'http://www.squeaksource.com/MetacelloRepository' 
			with: 'http://seaside.gemstone.com/ss/metacello') do: [:repositoryUrl |
				([
					Smalltalk at: #Gofer ifAbsent: [
					"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
						self bootstrapPackage: 'Gofer-Core-lr.115' from: repositoryUrl ].
					Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
						gofer := goferClass new
							url: repositoryUrl;
							yourself.
						[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
						gofer load ]]
							on: Error
							do: [ :ex |
								error := ex.
								Transcript 
									cr; 
									show: 'failed ensureMetacello: ';
									show: ex description printString;
									show: '...retrying'.
								"try again"
								ex return: nil ]) ~~ nil
					ifTrue: [
						"load 'default' group of Metacello"
						(Smalltalk at: #ConfigurationOfMetacello) perform: #load.
						^self ]].
		"shouldn't get here unless the load failed ... throw an error"
		self error: 'retry with alternate repository failed: ', error description printString ]! !

!MetacelloBaseConfiguration class methodsFor: 'metacello tool support' stamp: 'DaleHenrichs 11/2/2010 14:03'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!MetacelloBaseConfiguration class methodsFor: 'loading' stamp: 'DaleHenrichs 11/2/2010 16:58'!
load
	"self load"

	^self project stableVersion load! !

!MetacelloBaseConfiguration class methodsFor: 'loading' stamp: 'DaleHenrichs 11/2/2010 16:57'!
loadBleedingEdge
	"self loadStable"

	^self project bleedingEdge load! !

!MetacelloBaseConfiguration class methodsFor: 'loading' stamp: 'DaleHenrichs 11/2/2010 16:58'!
loadDevelopment
	"self loadDevelopment"

	^self project development load! !

!MetacelloBaseConfiguration class methodsFor: 'loading' stamp: 'DaleHenrichs 11/2/2010 16:58'!
loadStable
	"self loadStable"

	^self project stableVersion load! !

!MetacelloBaseConfiguration class methodsFor: 'accessing' stamp: 'DaleHenrichs 11/2/2010 14:03'!
project

	^self new project! !

!MetacelloBaseConfiguration class methodsFor: 'unloading Metacello' stamp: 'DaleHenrichs 11/2/2010 16:54'!
unloadMetacello

	| gofer |
	gofer := (Smalltalk at: #Gofer) new.
	MCWorkingCopy allManagers do: [:wc |
		((wc packageName beginsWith: 'Metacello') or: [ wc packageName beginsWith: 'OB-Metacello' ])
			ifTrue: [ gofer package: wc packageName ]].
	gofer unload.! !

!MetacelloBaseConfiguration class methodsFor: 'validation' stamp: 'DaleHenrichs 11/3/2010 16:02'!
validate

	^(Smalltalk at: #MetacelloMCVersionValidator) validate: self! !

!MetacelloBaseConfiguration methodsFor: 'defaults' stamp: 'DaleHenrichs 11/3/2010 11:30'!
bleedingEdge 
	"override if different behavior desired ... can signal MetacelloSymbolicVersionDoesNotExistError to indicate that #bleedingEdge version not allowed"
	
	^self defaultBleedingEdgeVersion! !

!MetacelloBaseConfiguration methodsFor: 'defaults' stamp: 'DaleHenrichs 11/3/2010 11:29'!
defaultBleedingEdgeVersion
	
	^(self project map values select: [ :version | 
		version blessing == #baseline ]) 
			detectMax: [ :version | version ]. ! !

!MetacelloBaseConfiguration methodsFor: 'defaults' stamp: 'DaleHenrichs 11/3/2010 11:29'!
defaultDevelopmentVersion
	
	| vrsns |
	vrsns := self project map values select: [ :version | 
		version blessing == #development ].
	vrsns isEmpty ifTrue: [ ^self bleedingEdge ]. 
	^vrsns detectMax: [ :version | version ]. ! !

!MetacelloBaseConfiguration methodsFor: 'defaults' stamp: 'DaleHenrichs 11/3/2010 11:29'!
defaultStableVersion 
	
	^(self project map values select: [ :version | 
		version blessing == #release ]) 
			detectMax: [ :version | version ]. ! !

!MetacelloBaseConfiguration methodsFor: 'accessing' stamp: 'DaleHenrichs 11/2/2010 14:03'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!MetacelloBaseConfiguration methodsFor: 'accessing' stamp: 'DaleHenrichs 11/2/2010 14:27'!
project: aProject

	project ifNil: [ self class ensureMetacello ].
	project := aProject! !

MetacelloBaseConfiguration subclass: #MetacelloSymbolicVersionExample1Config
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-Base'!

!MetacelloSymbolicVersionExample1Config methodsFor: 'baselines' stamp: 'DaleHenrichs 11/2/2010 12:51'!
baseline10: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.example.com/Example'.
		
		spec 
			package: 'Example-Core';
			package: 'Example-Tests' with: [ spec requires: 'Example-Core' ];
			package: 'Example-AddOn' with: [ spec requires: 'Example-Core' ];
			package: 'Example-AddOnTests' with: [ 
				spec requires: #('Example-AddOn' 'Example-Tests' ) ].
		spec 
			group: 'default' with: #('Example-Core' 'Example-AddOn' );
			group: 'Tests' with: #('Example-Tests' 'Example-AddOnTests' ) ].
! !

!MetacelloSymbolicVersionExample1Config methodsFor: 'baselines' stamp: 'DaleHenrichs 11/2/2010 12:51'!
baseline13: spec 
	<version: '1.3-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.example.com/Example'.
		
		spec 
			package: 'Example-Core' with: [
				spec includes: #('Example-Platform' ) ];
			package: 'Example-Tests' with: [ spec requires: 'Example-Core' ];
			package: 'Example-AddOn' with: [ spec requires: 'Example-Core' ];
			package: 'Example-Platform' with: [ spec requires: 'Example-Core' ];
			package: 'Example-AddOnTests' with: [ 
				spec requires: #('Example-AddOn' 'Example-Tests' ) ].
		spec 
			group: 'default' with: #('Example-Core' 'Example-AddOn' );
			group: 'Tests' with: #('Example-Tests' 'Example-AddOnTests' ) ].
	spec for: #gemstone do: [
		spec package: 'Example-Platform' with: 'Example-Platform.gemstone'.].
	spec for: #pharo do: [
		spec package: 'Example-Platform' with: 'Example-Platform.pharo'.].
	spec for: #squeak do: [
		spec package: 'Example-Platform' with: 'Example-Platform.squeak'.].! !

!MetacelloSymbolicVersionExample1Config methodsFor: 'symbolic versions' stamp: 'DaleHenrichs 11/2/2010 13:51'!
development: spec 
	<symbolicVersion: #development>
	
	spec for: #'common' version: '1.4'. 
! !

!MetacelloSymbolicVersionExample1Config methodsFor: 'symbolic versions' stamp: 'DaleHenrichs 11/2/2010 13:49'!
stable: spec 
	<symbolicVersion: #stable>
	
	spec for: #'common' version: '1.0'. 
! !

!MetacelloSymbolicVersionExample1Config methodsFor: 'versions' stamp: 'DaleHenrichs 11/2/2010 13:06'!
version10: spec 
	<version: '1.0' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #release.
		spec 
			package: 'Example-Core' with: 'Example-Core-anon.14';
			package: 'Example-Tests' with: 'Example-Tests-anon.3';
			package: 'Example-AddOn' with: 'Example-AddOn-anon.1';
			package: 'Example-AddOnTests' with: 'Example-AddOnTests-anon.1' ].
! !

!MetacelloSymbolicVersionExample1Config methodsFor: 'versions' stamp: 'DaleHenrichs 11/2/2010 13:08'!
version13: spec 
	<version: '1.3' imports: #('1.3-baseline')>
	
	spec for: #common do: [
		spec blessing: #release.
		spec description: 'Add in doits for Example-Core'.
		spec author: 'dkh'.
		spec timestamp: '10/13/2009 14:27'.
		spec 
			package: 'Example-Core' with: 'Example-Core-anon.17';
			package: 'Example-Tests' with: 'Example-Tests-anon.6';
			package: 'Example-AddOn' with: 'Example-AddOn-anon.1';
			package: 'Example-AddOnTests' with: 'Example-AddOnTests-anon.1' ].
	spec for: #gemstone do: [
		spec blessing: #development.
		spec package: 'Example-Platform' with: 'Example-Platform.gemstone-dkh.4'.].
	spec for: #pharo do: [
		spec package: 'Example-Platform' with: 'Example-Platform.pharo-dkh.7'.].
	spec for: #squeak do: [
		spec package: 'Example-Platform' with: 'Example-Platform.squeak-dkh.3'.].! !

!MetacelloSymbolicVersionExample1Config methodsFor: 'versions' stamp: 'DaleHenrichs 11/2/2010 13:06'!
version14: spec 
	<version: '1.4' imports: #('1.3-baseline')>
	
	spec for: #common do: [
		spec blessing: #development.
		spec description: ''.
		spec author: 'dkh'.
		spec timestamp: '11/2/2010 13:06'.
		spec 
			package: 'Example-Core' with: 'Example-Core-anon.18';
			package: 'Example-Tests' with: 'Example-Tests-anon.7';
			package: 'Example-AddOn' with: 'Example-AddOn-anon.1';
			package: 'Example-AddOnTests' with: 'Example-AddOnTests-anon.1' ].
	spec for: #gemstone do: [
		spec package: 'Example-Platform' with: 'Example-Platform.gemstone-dkh.4'.].
	spec for: #pharo do: [
		spec package: 'Example-Platform' with: 'Example-Platform.pharo-dkh.7'.].
	spec for: #squeak do: [
		spec package: 'Example-Platform' with: 'Example-Platform.squeak-dkh.3'.].! !

MetacelloBaseConfiguration subclass: #MetacelloSymbolicVersionExample2Config
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-Base'!

!MetacelloSymbolicVersionExample2Config methodsFor: 'baselines' stamp: 'DaleHenrichs 11/3/2010 11:30'!
baseline10: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.example.com/Example'.
		
		spec 
			package: 'Example-Core';
			package: 'Example-Tests' with: [ spec requires: 'Example-Core' ];
			package: 'Example-AddOn' with: [ spec requires: 'Example-Core' ];
			package: 'Example-AddOnTests' with: [ 
				spec requires: #('Example-AddOn' 'Example-Tests' ) ].
		spec 
			group: 'default' with: #('Example-Core' 'Example-AddOn' );
			group: 'Tests' with: #('Example-Tests' 'Example-AddOnTests' ) ].
! !

!MetacelloSymbolicVersionExample2Config methodsFor: 'baselines' stamp: 'DaleHenrichs 11/3/2010 11:30'!
baseline13: spec 
	<version: '1.3-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.example.com/Example'.
		
		spec 
			package: 'Example-Core' with: [
				spec includes: #('Example-Platform' ) ];
			package: 'Example-Tests' with: [ spec requires: 'Example-Core' ];
			package: 'Example-AddOn' with: [ spec requires: 'Example-Core' ];
			package: 'Example-Platform' with: [ spec requires: 'Example-Core' ];
			package: 'Example-AddOnTests' with: [ 
				spec requires: #('Example-AddOn' 'Example-Tests' ) ].
		spec 
			group: 'default' with: #('Example-Core' 'Example-AddOn' );
			group: 'Tests' with: #('Example-Tests' 'Example-AddOnTests' ) ].
	spec for: #gemstone do: [
		spec package: 'Example-Platform' with: 'Example-Platform.gemstone'.].
	spec for: #pharo do: [
		spec package: 'Example-Platform' with: 'Example-Platform.pharo'.].
	spec for: #squeak do: [
		spec package: 'Example-Platform' with: 'Example-Platform.squeak'.].! !

!MetacelloSymbolicVersionExample2Config methodsFor: 'symbolic versions' stamp: 'DaleHenrichs 11/3/2010 11:31'!
development

	^self defaultDevelopmentVersion! !

!MetacelloSymbolicVersionExample2Config methodsFor: 'symbolic versions' stamp: 'DaleHenrichs 11/3/2010 11:31'!
stable
	
	^self defaultStableVersion
! !

!MetacelloSymbolicVersionExample2Config methodsFor: 'versions' stamp: 'DaleHenrichs 11/3/2010 11:30'!
version10: spec 
	<version: '1.0' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #release.
		spec 
			package: 'Example-Core' with: 'Example-Core-anon.14';
			package: 'Example-Tests' with: 'Example-Tests-anon.3';
			package: 'Example-AddOn' with: 'Example-AddOn-anon.1';
			package: 'Example-AddOnTests' with: 'Example-AddOnTests-anon.1' ].
! !

!MetacelloSymbolicVersionExample2Config methodsFor: 'versions' stamp: 'DaleHenrichs 11/3/2010 11:30'!
version13: spec 
	<version: '1.3' imports: #('1.3-baseline')>
	
	spec for: #common do: [
		spec blessing: #release.
		spec description: 'Add in doits for Example-Core'.
		spec author: 'dkh'.
		spec timestamp: '10/13/2009 14:27'.
		spec 
			package: 'Example-Core' with: 'Example-Core-anon.17';
			package: 'Example-Tests' with: 'Example-Tests-anon.6';
			package: 'Example-AddOn' with: 'Example-AddOn-anon.1';
			package: 'Example-AddOnTests' with: 'Example-AddOnTests-anon.1' ].
	spec for: #gemstone do: [
		spec blessing: #development.
		spec package: 'Example-Platform' with: 'Example-Platform.gemstone-dkh.4'.].
	spec for: #pharo do: [
		spec package: 'Example-Platform' with: 'Example-Platform.pharo-dkh.7'.].
	spec for: #squeak do: [
		spec package: 'Example-Platform' with: 'Example-Platform.squeak-dkh.3'.].! !

!MetacelloSymbolicVersionExample2Config methodsFor: 'versions' stamp: 'DaleHenrichs 11/3/2010 11:30'!
version14: spec 
	<version: '1.4' imports: #('1.3-baseline')>
	
	spec for: #common do: [
		spec blessing: #development.
		spec description: ''.
		spec author: 'dkh'.
		spec timestamp: '11/2/2010 13:06'.
		spec 
			package: 'Example-Core' with: 'Example-Core-anon.18';
			package: 'Example-Tests' with: 'Example-Tests-anon.7';
			package: 'Example-AddOn' with: 'Example-AddOn-anon.1';
			package: 'Example-AddOnTests' with: 'Example-AddOnTests-anon.1' ].
	spec for: #gemstone do: [
		spec package: 'Example-Platform' with: 'Example-Platform.gemstone-dkh.4'.].
	spec for: #pharo do: [
		spec package: 'Example-Platform' with: 'Example-Platform.pharo-dkh.7'.].
	spec for: #squeak do: [
		spec package: 'Example-Platform' with: 'Example-Platform.squeak-dkh.3'.].! !
